pub struct PositionalBarPlot<'a> { /* private fields */ }Expand description
Bar plot with explicit X positions
Implementations
Sourceimpl<'a> PositionalBarPlot<'a>
impl<'a> PositionalBarPlot<'a>
Sourcepub fn new(label: &'a str, x_data: &'a [f64], y_data: &'a [f64]) -> Self
pub fn new(label: &'a str, x_data: &'a [f64], y_data: &'a [f64]) -> Self
Create a new positional bar plot with explicit X and Y data
Sourcepub fn with_bar_size(self, bar_size: f64) -> Self
pub fn with_bar_size(self, bar_size: f64) -> Self
Set the bar width (in plot units)
Sourcepub fn with_style(self, style: PlotItemStyle) -> Self
pub fn with_style(self, style: PlotItemStyle) -> Self
Set ImPlotSpec-backed style overrides for this positional bar plot.
Sourcepub fn with_flags(self, flags: BarsFlags) -> Self
pub fn with_flags(self, flags: BarsFlags) -> Self
Set bar flags for customization
Sourcepub fn with_item_flags(self, flags: ItemFlags) -> Self
pub fn with_item_flags(self, flags: ItemFlags) -> Self
Set common item flags for this plot item (applies to all plot types)