pub struct SimpleBarGroupsPlot<'a> { /* private fields */ }Expand description
Simple bar groups plot with automatic layout
Implementations
Sourceimpl<'a> SimpleBarGroupsPlot<'a>
impl<'a> SimpleBarGroupsPlot<'a>
Sourcepub fn new(labels: Vec<&'a str>, data: Vec<Vec<f64>>) -> Self
pub fn new(labels: Vec<&'a str>, data: Vec<Vec<f64>>) -> Self
Create a simple bar groups plot from a 2D data structure
Arguments
labels- Labels for each seriesdata- Vector of vectors, where each inner vector is a series
Sourcepub fn with_style(self, style: PlotItemStyle) -> Self
pub fn with_style(self, style: PlotItemStyle) -> Self
Set ImPlotSpec-backed style overrides for this bar groups plot.
Sourcepub fn with_group_size(self, group_size: f64) -> Self
pub fn with_group_size(self, group_size: f64) -> Self
Set the group size
Sourcepub fn with_flags(self, flags: BarGroupsFlags) -> Self
pub fn with_flags(self, flags: BarGroupsFlags) -> Self
Set flags
Sourcepub fn with_item_flags(self, flags: ItemFlags) -> Self
pub fn with_item_flags(self, flags: ItemFlags) -> Self
Set common item flags for this plot item (applies to all plot types)
Sourcepub fn horizontal(self) -> Self
pub fn horizontal(self) -> Self
Make bars horizontal