pub struct SimpleDigitalPlot<'a> { /* private fields */ }Expand description
Simple digital plot for single array data (y values only, x is auto-generated)
Implementations
Sourceimpl<'a> SimpleDigitalPlot<'a>
impl<'a> SimpleDigitalPlot<'a>
Sourcepub fn new(label: &'a str, y_data: &'a [f64]) -> Self
pub fn new(label: &'a str, y_data: &'a [f64]) -> Self
Create a new simple digital plot with only y data
Sourcepub fn with_x_scale(self, x_scale: f64) -> Self
pub fn with_x_scale(self, x_scale: f64) -> Self
Set the x scale (spacing between points)
Sourcepub fn with_x_start(self, x_start: f64) -> Self
pub fn with_x_start(self, x_start: f64) -> Self
Set the x start value
Sourcepub fn with_flags(self, flags: DigitalFlags) -> Self
pub fn with_flags(self, flags: DigitalFlags) -> Self
Set digital flags
Sourcepub fn with_style(self, style: PlotItemStyle) -> Self
pub fn with_style(self, style: PlotItemStyle) -> Self
Set ImPlotSpec-backed style overrides for this digital plot.
Sourcepub fn with_item_flags(self, flags: ItemFlags) -> Self
pub fn with_item_flags(self, flags: ItemFlags) -> Self
Set common item flags for this plot item (applies to all plot types)