AsymmetricErrorBarsPlot

Struct AsymmetricErrorBarsPlot 

pub struct AsymmetricErrorBarsPlot<'a> { /* private fields */ }
Builder for asymmetric error bars plots

Implementations

Source

impl<'a> AsymmetricErrorBarsPlot<'a>

pub fn new( label: &'a str, x_data: &'a [f64], y_data: &'a [f64], err_neg: &'a [f64], err_pos: &'a [f64], ) -> Self

Create a new asymmetric error bars plot

Arguments
  • label - The label for the error bars
  • x_data - X coordinates of the data points
  • y_data - Y coordinates of the data points
  • err_neg - Negative error values (downward/leftward)
  • err_pos - Positive error values (upward/rightward)
pub fn with_flags(self, flags: ErrorBarsFlags) -> Self

Set error bar flags for customization

pub fn with_item_flags(self, flags: ItemFlags) -> Self

Set common item flags for this plot item (applies to all plot types)

pub unsafe fn with_data_layout(self, layout: PlotDataLayout) -> Self

Set the data layout used to read values.

Safety

Every sample address computed from layout must refer to an initialized, properly aligned f64 within every data allocation retained by this builder.

pub fn with_offset(self, offset: PlotDataOffset) -> Self

Set the sample-index offset used to read values.

pub unsafe fn with_stride(self, stride: PlotDataStride) -> Self

Set the byte stride used to read values.

Safety

Every strided sample read must remain initialized, aligned, and within every data allocation retained by this builder.

pub fn horizontal(self) -> Self

Make error bars horizontal instead of vertical

pub fn validate(&self) -> Result<(), PlotError>

Validate the plot data