pub struct ImagePlot<'a> { /* private fields */ }Expand description
Plot an image in plot coordinates using an ImTextureID
Implementations
Sourceimpl<'a> ImagePlot<'a>
impl<'a> ImagePlot<'a>
pub fn new( label: &'a str, tex_id: ImTextureID, bounds_min: ImPlotPoint, bounds_max: ImPlotPoint, ) -> Self
pub fn with_uv(self, uv0: [f32; 2], uv1: [f32; 2]) -> Self
pub fn with_tint(self, tint: [f32; 4]) -> Self
pub fn with_flags(self, flags: ImageFlags) -> Self
Sourcepub fn with_item_flags(self, flags: ItemFlags) -> Self
pub fn with_item_flags(self, flags: ItemFlags) -> Self
Set common item flags for this plot item (applies to all plot types)
pub fn validate(&self) -> Result<(), PlotError>