pub struct PieChartPlotF32<'a> { /* private fields */ }Expand description
Float version of pie chart for better performance with f32 data
Implementations
Sourceimpl<'a> PieChartPlotF32<'a>
impl<'a> PieChartPlotF32<'a>
Sourcepub fn new(
label_ids: Vec<&'a str>,
values: &'a [f32],
center_x: f64,
center_y: f64,
radius: f64,
) -> Self
pub fn new( label_ids: Vec<&'a str>, values: &'a [f32], center_x: f64, center_y: f64, radius: f64, ) -> Self
Create a new f32 pie chart plot
Sourcepub fn with_label_format(self, fmt: Option<&'a str>) -> Self
pub fn with_label_format(self, fmt: Option<&'a str>) -> Self
Set the label format for slice values
Sourcepub fn with_start_angle(self, angle: f64) -> Self
pub fn with_start_angle(self, angle: f64) -> Self
Set the starting angle in degrees
Sourcepub fn with_flags(self, flags: PieChartFlags) -> Self
pub fn with_flags(self, flags: PieChartFlags) -> Self
Set pie chart flags for customization
Sourcepub fn with_item_flags(self, flags: ItemFlags) -> Self
pub fn with_item_flags(self, flags: ItemFlags) -> Self
Set common item flags for this plot item (applies to all plot types)
Ignore hidden slices when drawing
Sourcepub fn no_slice_border(self) -> Self
pub fn no_slice_border(self) -> Self
Draw slices without the per-slice border stroke.