pub struct SimpleScatterPlot<'a> { /* private fields */ }Expand description
Simple scatter plot for quick plotting without builder pattern
Implementations
Sourceimpl<'a> SimpleScatterPlot<'a>
impl<'a> SimpleScatterPlot<'a>
Sourcepub fn new(label: &'a str, values: &'a [f64]) -> Self
pub fn new(label: &'a str, values: &'a [f64]) -> Self
Create a simple scatter plot with Y values only (X will be indices)
Sourcepub fn with_style(self, style: PlotItemStyle) -> Self
pub fn with_style(self, style: PlotItemStyle) -> Self
Replace the entire item style override for this scatter plot.
Sourcepub fn with_line_color(self, color: [f32; 4]) -> Self
pub fn with_line_color(self, color: [f32; 4]) -> Self
Set the scatter line color. Use the alpha channel to control transparency.
Sourcepub fn with_line_weight(self, weight: f32) -> Self
pub fn with_line_weight(self, weight: f32) -> Self
Set the outline width in pixels.
Sourcepub fn with_marker(self, marker: Marker) -> Self
pub fn with_marker(self, marker: Marker) -> Self
Set the marker type for the scatter plot.
Sourcepub fn with_marker_size(self, size: f32) -> Self
pub fn with_marker_size(self, size: f32) -> Self
Set the marker size in pixels.
Sourcepub fn with_marker_line_color(self, color: [f32; 4]) -> Self
pub fn with_marker_line_color(self, color: [f32; 4]) -> Self
Set the marker outline color.
Sourcepub fn with_marker_fill_color(self, color: [f32; 4]) -> Self
pub fn with_marker_fill_color(self, color: [f32; 4]) -> Self
Set the marker fill color.
Sourcepub fn with_flags(self, flags: ScatterFlags) -> Self
pub fn with_flags(self, flags: ScatterFlags) -> Self
Set scatter flags for customization
Sourcepub fn with_item_flags(self, flags: ItemFlags) -> Self
pub fn with_item_flags(self, flags: ItemFlags) -> Self
Set common item flags for this plot item (applies to all plot types)
Sourcepub fn with_x_scale(self, scale: f64) -> Self
pub fn with_x_scale(self, scale: f64) -> Self
Set X scale factor
Sourcepub fn with_x_start(self, start: f64) -> Self
pub fn with_x_start(self, start: f64) -> Self
Set X start value