pub struct PlotDataLayout { /* private fields */ }Expand description
Data layout used by ImPlot item builders.
Implementations
Sourceimpl PlotDataLayout
impl PlotDataLayout
Sourcepub const fn new(offset: PlotDataOffset, stride: PlotDataStride) -> Self
pub const fn new(offset: PlotDataOffset, stride: PlotDataStride) -> Self
Create a data layout from a sample offset and byte stride.
Sourcepub const fn with_offset(self, offset: PlotDataOffset) -> Self
pub const fn with_offset(self, offset: PlotDataOffset) -> Self
Create a data layout with a different sample offset.
Sourcepub const fn with_stride(self, stride: PlotDataStride) -> Self
pub const fn with_stride(self, stride: PlotDataStride) -> Self
Create a data layout with a different byte stride.