PlotClipRectToken

Struct PlotClipRectToken 

pub struct PlotClipRectToken<'plot> { /* private fields */ }
Token for a pushed ImPlot plot clip rect.

Implementations

Source

impl PlotClipRectToken<'_>

pub fn pop(self)

Pop the plot clip rect immediately instead of waiting for drop.

pub fn end(self)

Pop the plot clip rect immediately instead of waiting for drop.