pub struct BarPlot<'a> { /* private fields */ }Expand description
Builder for bar plots with customization options
Implementations
Sourceimpl<'a> BarPlot<'a>
impl<'a> BarPlot<'a>
Sourcepub fn new(label: &'a str, values: &'a [f64]) -> Self
pub fn new(label: &'a str, values: &'a [f64]) -> Self
Create a new bar plot with the given label and values
Sourcepub fn with_bar_size(self, bar_size: f64) -> Self
pub fn with_bar_size(self, bar_size: f64) -> Self
Set the bar width (in plot units)
Sourcepub fn with_style(self, style: PlotItemStyle) -> Self
pub fn with_style(self, style: PlotItemStyle) -> Self
Set ImPlotSpec-backed style overrides for this bar plot.
Sourcepub fn with_shift(self, shift: f64) -> Self
pub fn with_shift(self, shift: f64) -> Self
Set the bar shift (in plot units)
Sourcepub fn with_flags(self, flags: BarsFlags) -> Self
pub fn with_flags(self, flags: BarsFlags) -> Self
Set bar flags for customization
Sourcepub fn with_item_flags(self, flags: ItemFlags) -> Self
pub fn with_item_flags(self, flags: ItemFlags) -> Self
Set common item flags for this plot item (applies to all plot types)
Sourcepub fn with_offset(self, offset: i32) -> Self
pub fn with_offset(self, offset: i32) -> Self
Set data offset for partial plotting
Sourcepub fn with_stride(self, stride: i32) -> Self
pub fn with_stride(self, stride: i32) -> Self
Set data stride for non-contiguous data