pub struct DummyPlot<'a> { /* private fields */ }Expand description
Builder for dummy plots
Dummy plots add a legend entry without plotting any actual data. This is useful for creating custom legend entries or placeholders.
Implementations
Sourceimpl<'a> DummyPlot<'a>
impl<'a> DummyPlot<'a>
Sourcepub fn with_flags(self, flags: DummyFlags) -> Self
pub fn with_flags(self, flags: DummyFlags) -> Self
Set dummy flags for customization
Sourcepub fn with_item_flags(self, flags: ItemFlags) -> Self
pub fn with_item_flags(self, flags: ItemFlags) -> Self
Set common item flags for this plot item (applies to all plot types)