pub struct PlotToken<'ui> { /* private fields */ }Expand description
Token that represents an active plot
The plot will be automatically ended when this token is dropped.
Implementations
Sourceimpl<'ui> PlotToken<'ui>
impl<'ui> PlotToken<'ui>
Sourcepub fn end(self)
pub fn end(self)
Manually end the plot
This is called automatically when the token is dropped, but you can call it manually if needed.
Sourcepub fn plot_draw_list(&self) -> Option<DrawListMut<'_>>
pub fn plot_draw_list(&self) -> Option<DrawListMut<'_>>
Get the active plot draw list as a frame-bound wrapper.
Sourcepub fn push_plot_clip_rect(&self, expand: f32) -> PlotClipRectToken<'_>
pub fn push_plot_clip_rect(&self, expand: f32) -> PlotClipRectToken<'_>
Push a plot clip rect on this active plot.
The returned token pops the clip rect when dropped and cannot outlive the active plot token it was created from.